import { LocalStorage, Platform } from 'quasar';
import { api } from '../index';
import { useMainStore } from './stores';
import { baseURL } from 'src/config';

export let db: SQLitePlugin.Database | null = null;

if (Platform.is.cordova) {
  document.addEventListener('deviceready', onDeviceReady);
}

interface ConfigResult {
  name: string;
  value: string;
}

function onDeviceReady() {
  db = window.sqlitePlugin.openDatabase({ name: 'flaschengeist.db', location: 'default' });
  db.transaction(function (transaction) {
    transaction.executeSql(
      'CREATE TABLE IF NOT EXISTS config_table (name STRING NOT NULL PRIMARY KEY, value STRING NOT NULL)'
    );
    transaction.executeSql(`INSERT INTO config_table VALUES ('baseUrl', '${baseURL.value}')`);
  });
  console.log('finish init database');
  const url = loadConfig();
  console.log('url is', url);
  if (url) {
  }
}

export function insertConfig(config: string, value: string) {
  console.log('insert config', config, value)
  console.log(db)
  db?.transaction((tx) => {

    console.log('insert', config, value)
    tx.executeSql(
      `INSERT INTO config_table VALUES ('${config}', '${value}')`,
      [],
      (tx1) => {
        console.log('success insert into database', tx1);
      },
      (tx, err) => {
        console.log('error insert into database', err);
        console.log('update database', config, value)
        tx.executeSql(
          `UPDATE config_table SET value='${value}' WHERE name='${config}'`,
          [],
          (tx1) => {
            console.log('success update database', tx1);
          },
          (tx, err) => {
            console.log('error update databes', err);
          }
        );
      }
    );
  })
}

export function deleteConfig(config: string) {
  db?.transaction((tx) => {
    tx.executeSql(
      `DELETE FROM config_table WHERE name='${config}'`,
      [],
      (tx1, results) => {
        console.log('success delete from database', tx1, results, results.rows.item(0));
      },
      (tx2, err) => {
        console.log('error delete from database', tx2, err);
      }
    );
  });
}

export function loadConfig() {
  let result = null;
  db?.transaction((tx) => {
    tx.executeSql(
      'SELECT value FROM config_table WHERE name="baseUrl"',
      [],
      (tx1, results) => {
        console.log('results', tx1, results, results.rows.item(0));
        result = (<ConfigResult>results.rows.item(0)).value;

        if (result !== LocalStorage.getItem<string>('baseURL')) {
          console.log('url has to change', result, LocalStorage.getItem<string>('baseURL'));
          LocalStorage.set('baseURL', result);
          api.defaults.baseURL = result;
          setTimeout(() => {
            window.location.reload();
          }, 1000);
        }
      },
      (tx2, err) => {
        console.log('error', tx2, err);
      }
    );
    tx.executeSql(
      'SELECT value FROM config_table WHERE name="session"',
      [],
      (tx1, results) => {
        console.log('results session', tx1, results, results.rows.item(0));
        let session: string | FG.Session = (<ConfigResult>results.rows.item(0)).value;
        console.log(session);
        if (session) {
          console.log('update session')
          session = <FG.Session>JSON.parse(session);
          console.log(session)
          session.expires = new Date(session.expires);
          console.log(session)
          const store = useMainStore();
          store.session = session;
          LocalStorage.set('session', store.session);
        }
      },
      (tx2, err) => {
        console.log('error load session', err);
      }
    );
  });
  return result;
}
